@@ -41,10 +41,9 @@
 #include "caja-notes-viewer.h"
 #include "caja-emblem-sidebar.h"
 #include "caja-image-properties-page.h"
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <fcntl.h>
 #include <string.h>
+#include <unistd.h>
 #include "caja-desktop-window.h"
 #include "caja-main.h"
 #include "caja-spatial-window.h"
@@ -56,7 +55,6 @@
 #include "caja-window-private.h"
 #include "caja-window-manage-views.h"
 #include "caja-freedesktop-dbus.h"
-#include <unistd.h>
 #include <libxml/xmlsave.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
@@ -70,6 +68,7 @@
 #include <libcaja-private/caja-file-utilities.h>
 #include <libcaja-private/caja-global-preferences.h>
 #include <libcaja-private/caja-extensions.h>
+#include <libcaja-private/caja-module.h>
 #include <libcaja-private/caja-desktop-link-monitor.h>
 #include <libcaja-private/caja-directory-private.h>
 #include <libcaja-private/caja-signaller.h>
@@ -90,8 +89,6 @@ enum {
 #define APPLICATION_WINDOW_MIN_WIDTH	300
 #define APPLICATION_WINDOW_MIN_HEIGHT	100
 
-#define START_STATE_CONFIG "start-state"
-
 #define CAJA_ACCEL_MAP_SAVE_DELAY 30
 
 /* Keeps track of all the desktop windows. */
