@@ -312,6 +312,12 @@ static void
 caja_path_bar_init (CajaPathBar *path_bar)
 {
     char *p;
+#if GTK_CHECK_VERSION(3, 0, 0)
+    GtkStyleContext *context;
+
+    context = gtk_widget_get_style_context (GTK_WIDGET (path_bar));
+    gtk_style_context_add_class (context, "caja-pathbar");
+#endif
 
     gtk_widget_set_has_window (GTK_WIDGET (path_bar), FALSE);
     gtk_widget_set_redraw_on_allocate (GTK_WIDGET (path_bar), FALSE);
@@ -1206,7 +1212,9 @@ caja_path_bar_scroll_timeout (CajaPathBar *path_bar)
 {
     gboolean retval = FALSE;
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
     GDK_THREADS_ENTER ();
+#endif
 
     if (path_bar->timer)
     {
@@ -1236,8 +1244,9 @@ caja_path_bar_scroll_timeout (CajaPathBar *path_bar)
         }
     }
 
-
+#if !GTK_CHECK_VERSION (3, 0, 0)
     GDK_THREADS_LEAVE ();
+#endif
 
     return retval;
 }
